AiBranch class
A compact "‹ 2/3 ›" control for navigating between alternate versions of a message (e.g. successive regenerations).
Purely presentational: it reports navigation via onPrevious/onNext and shows index of total (both 1-based for display; pass a 0-based index).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AiBranch
Constructors
- AiBranch({Key? key, required int index, required int total, VoidCallback? onPrevious, VoidCallback? onNext})
-
Creates a branch navigator.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
The 0-based index of the current version.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onNext → VoidCallback?
-
Called to go to the next version. Disabled at the last.
final
- onPrevious → VoidCallback?
-
Called to go to the previous version. Disabled at the first.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
The total number of versions.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited