ReasoningDelta class final
- Inheritance
-
- Object
- AiStreamEvent
- ReasoningDelta
Constructors
- ReasoningDelta({required String messageId, required String delta, String? signature})
-
Creates a reasoning-delta event.
const
-
ReasoningDelta.fromJson(Map<
String, Object?> json) -
Reconstructs a ReasoningDelta from
json.factory
Properties
- delta → String
-
The reasoning fragment to append.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → String
-
The message receiving the reasoning.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String?
-
An opaque provider signature for the reasoning block (set on the
ReasoningPart when present); see ReasoningPart.signature.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Serializes this event, including its
typediscriminator.override -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override